package com.sf.msg.service;

package ..deTemp.1734792466071;

import com.smartframework.web.core.utils.Constants;
import com.smartframework.web.core.utils.ParameterUtils;
import com.smartframework.web.core.utils.SFTPUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPReply;
import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;

public class DmsMessageSendService {
  static Logger logger = Logger.getLogger(com.sf.msg.service.DmsMessageSendService.class);
  
  public Map<String, String> send(Map<String, Object> vars, String msgContent, List<String> addresses) throws Exception {
    String fileName = String.valueOf(vars.get("fileName"));
    if (ParameterUtils.isEmptyOrNull(fileName)) {
      logger.debug("没有指定文件名则 发送临时短信");
      fileName = "fas-system-temp-msg" + (new Date()).getTime();
    } 
    logger.debug(String.format("短信发送内容:%s,接收人:%s", new Object[] { msgContent, 
            ParameterUtils.join(addresses, ",") }));
    String fileSubFoldler = String.valueOf(vars.get("fileFolder"));
    String path = Constants.getString("file.upload.location", "D:/dms-sms/");
    if (!ParameterUtils.isEmptyOrNull(fileSubFoldler) && !fileSubFoldler.equals("default"))
      path = path + fileSubFoldler; 
    logger.debug("文件路径： " + path);
    File smsSaveFolder = new File(path);
    if (!smsSaveFolder.exists())
      smsSaveFolder.mkdirs(); 
    String ret = "success";
    if (!ParameterUtils.isEmptyOrNull(msgContent)) {
      String fullName = path + File.separator + fileName + ".xml";
      fullName = fullName.replace("\\", "/");
      try {
        logger.debug("开始生成文件");
        DOM4Jcreate(fullName, msgContent, addresses);
      } catch (Exception e) {
        logger.warn("生成短信XML文件时发生异常", e);
        throw e;
      } 
      try {
        boolean flag = uploadFile(path, fileName);
        if (!flag)
          ret = "FTP传输失败"; 
      } catch (Exception e) {
        logger.warn(ret, e);
      } 
    } 
    Map<String, String> m = new HashMap<>();
    for (String add : addresses)
      m.put(add, ret); 
    return m;
  }
  
  public static boolean uploadFile(String path, String filename) {
    if (Constants.integerConfigIsEnabled("dms.sms.ftp.disabled"))
      return true; 
    filename = filename + ".xml";
    InputStream input = null;
    String fileFullName = path + File.separator + filename;
    try {
      input = new FileInputStream(new File(fileFullName));
    } catch (FileNotFoundException e1) {
      logger.warn("文件" + fileFullName + " 不存在");
      return false;
    } 
    boolean success = false;
    String url = Constants.getString("dms.sms.ftp.server", "");
    Integer port = Constants.getInteger("dms.sms.ftp.port", Integer.valueOf(21));
    String username = Constants.getString("dms.sms.ftp.user", "");
    String password = Constants.getString("dms.sms.ftp.password", "");
    String workingDirectory = Constants.getString("dms.sms.ftp.wrokdir", "/");
    String sftpOrFtp = Constants.getString("dms.sms.sftp.ftp", "ftp");
    if (sftpOrFtp.equals("ftp")) {
      FTPClient ftp = new FTPClient();
      try {
        logger.debug("使用FTP发送短信:" + fileFullName);
        ftp.connect(url, port.intValue());
        ftp.login(username, password);
        int reply = ftp.getReplyCode();
        logger.debug("使用FTP发送短信:" + fileFullName + ",reply:" + reply);
        if (!FTPReply.isPositiveCompletion(reply)) {
          ftp.disconnect();
          logger.debug("FTP断开");
        } else {
          ftp.changeWorkingDirectory(workingDirectory);
          ftp.setFileType(2);
          ftp.setControlEncoding("UTF-8");
          ftp.enterLocalPassiveMode();
          if (ftp.storeFile(new String(filename.getBytes("UTF-8"), "iso-8859-1"), input)) {
            logger.debug("使用FTP发送短信:" + fileFullName + " 完成");
            success = true;
          } else {
            logger.debug("使用FTP发送短信:" + fileFullName + " 失败");
            success = false;
          } 
        } 
        input.close();
        ftp.logout();
      } catch (Exception e) {
        logger.debug("FTP 连接异常", e);
        return false;
      } finally {
        if (ftp.isConnected())
          try {
            ftp.disconnect();
          } catch (IOException ioe) {
            logger.debug("FTP断开异常", ioe);
          }  
      } 
    } else {
      String sftpUrl = "sftp://" + username + ":" + password + "@" + url + ":" + port;
      logger.debug("sftp服务地址" + sftpUrl);
      logger.debug("上传文件所在地址" + fileFullName);
      try {
        SFTPUtil.newClient(sftpUrl).login().autoLogOut()
          .upload(workingDirectory, new File(fileFullName));
        logger.debug("使用SFTP发送短信:" + fileFullName + " 完成");
        success = true;
      } catch (Exception e1) {
        e1.printStackTrace();
        logger.debug("使用SFTP发送短信失败");
      } 
    } 
    return success;
  }
  
  private void DOM4Jcreate(String path, String alarmContent, List<String> phoneArray) throws Exception {
    Document document = DocumentHelper.createDocument();
    Element root = document.addElement("content");
    root.addAttribute("name", alarmContent);
    Element iphones = root.addElement("iphones");
    for (String phone : phoneArray) {
      Element iphone = iphones.addElement("iphone");
      iphone.addAttribute("name", phone);
    } 
    logger.debug("生成文件路径: " + path);
    File file = new File(path + File.separator);
    logger.debug("文件生成成功");
    XMLWriter writer = new XMLWriter(new FileOutputStream(file), OutputFormat.createPrettyPrint());
    writer.setEscapeText(false);
    writer.write(document);
    writer.close();
  }
}
